% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat-qq-line.R, R/stat-qq.r
\name{geom_qq_line}
\alias{geom_qq_line}
\alias{stat_qq_line}
\alias{geom_qq}
\alias{stat_qq}
\title{A quantile-quantile plot}
\usage{
geom_qq_line(mapping = NULL, data = NULL, geom = "path",
  position = "identity", ..., distribution = stats::qnorm,
  dparams = list(), line.p = c(0.25, 0.75), fullrange = FALSE,
  na.rm = FALSE, show.legend = NA, inherit.aes = TRUE)

stat_qq_line(mapping = NULL, data = NULL, geom = "path",
  position = "identity", ..., distribution = stats::qnorm,
  dparams = list(), line.p = c(0.25, 0.75), fullrange = FALSE,
  na.rm = FALSE, show.legend = NA, inherit.aes = TRUE)

geom_qq(mapping = NULL, data = NULL, geom = "point",
  position = "identity", ..., distribution = stats::qnorm,
  dparams = list(), na.rm = FALSE, show.legend = NA, inherit.aes = TRUE)

stat_qq(mapping = NULL, data = NULL, geom = "point",
  position = "identity", ..., distribution = stats::qnorm,
  dparams = list(), na.rm = FALSE, show.legend = NA, inherit.aes = TRUE)
}
\arguments{
\item{mapping}{Set of aesthetic mappings created by \code{\link[=aes]{aes()}} or
\code{\link[=aes_]{aes_()}}. If specified and \code{inherit.aes = TRUE} (the
default), it is combined with the default mapping at the top level of the
plot. You must supply \code{mapping} if there is no plot mapping.}

\item{data}{The data to be displayed in this layer. There are three
options:

If \code{NULL}, the default, the data is inherited from the plot
data as specified in the call to \code{\link[=ggplot]{ggplot()}}.

A \code{data.frame}, or other object, will override the plot
data. All objects will be fortified to produce a data frame. See
\code{\link[=fortify]{fortify()}} for which variables will be created.

A \code{function} will be called with a single argument,
the plot data. The return value must be a \code{data.frame.}, and
will be used as the layer data.}

\item{geom}{The geometric object to use display the data}

\item{position}{Position adjustment, either as a string, or the result of
a call to a position adjustment function.}

\item{...}{Other arguments passed on to \code{\link[=layer]{layer()}}. These are
often aesthetics, used to set an aesthetic to a fixed value, like
\code{color = "red"} or \code{size = 3}. They may also be parameters
to the paired geom/stat.}

\item{distribution}{Distribution function to use, if x not specified}

\item{dparams}{Additional parameters passed on to \code{distribution}
function.}

\item{line.p}{Vector of quantiles to use when fitting the Q-Q line, defaults
defaults to \code{c(.25, .75)}.}

\item{fullrange}{Should the q-q line span the full range of the plot, or just
the data}

\item{na.rm}{If \code{FALSE}, the default, missing values are removed with
a warning. If \code{TRUE}, missing values are silently removed.}

\item{show.legend}{logical. Should this layer be included in the legends?
\code{NA}, the default, includes if any aesthetics are mapped.
\code{FALSE} never includes, and \code{TRUE} always includes.
It can also be a named logical vector to finely select the aesthetics to
display.}

\item{inherit.aes}{If \code{FALSE}, overrides the default aesthetics,
rather than combining with them. This is most useful for helper functions
that define both data and aesthetics and shouldn't inherit behaviour from
the default plot specification, e.g. \code{\link[=borders]{borders()}}.}
}
\description{
\code{geom_qq} and \code{stat_qq} produce quantile-quantile plots. \code{geom_qq_line} and
\code{stat_qq_line} compute the slope and intercept of the line connecting the
points at specified quartiles of the theoretical and sample distributions.
}
\section{Aesthetics}{

\code{stat_qq} understands the following aesthetics (required aesthetics are in bold):
\itemize{
\item \strong{\code{sample}}
\item \code{group}
\item \code{x}
\item \code{y}
}
Learn more about setting these aesthetics in \code{vignette("ggplot2-specs")}


\code{stat_qq_line} understands the following aesthetics (required aesthetics are in bold):
\itemize{
\item \strong{\code{sample}}
\item \code{group}
\item \code{x}
\item \code{y}
}
Learn more about setting these aesthetics in \code{vignette("ggplot2-specs")}
}

\section{Computed variables}{

Variables computed by \code{stat_qq}:
\describe{
\item{sample}{sample quantiles}
\item{theoretical}{theoretical quantiles}
}
Variables computed by \code{stat_qq_line}:
\describe{
\item{x}{x-coordinates of the endpoints of the line segment connecting the
points at the chosen quantiles of the theoretical and the sample
distributions}
\item{y}{y-coordinates of the endpoints}
}
}

\examples{
\donttest{
df <- data.frame(y = rt(200, df = 5))
p <- ggplot(df, aes(sample = y))
p + stat_qq() + stat_qq_line()

# Use fitdistr from MASS to estimate distribution params
params <- as.list(MASS::fitdistr(df$y, "t")$estimate)
ggplot(df, aes(sample = y)) +
  stat_qq(distribution = qt, dparams = params["df"]) +
  stat_qq_line(distribution = qt, dparams = params["df"])

# Using to explore the distribution of a variable
ggplot(mtcars, aes(sample = mpg)) +
  stat_qq() +
  stat_qq_line()
ggplot(mtcars, aes(sample = mpg, colour = factor(cyl))) +
  stat_qq() +
  stat_qq_line()
}
}
